Slides in ReStructuredText
==========================

This works as well.

----

Here we Go
----------

This is foo

This is bar

- This
- Is
- A
- List

----

Here we Go Again
----------------

This is foo again

This is bargain
